==> opencv_camera-0.10.11.tar.gz: opencv_camera-0.10.11/opencv_camera/display/lines.py <==
##############################################
# The MIT License (MIT)
# Copyright (c) 2014 Kevin Walchko
# see LICENSE for full details
##############################################
# -*- coding: utf-8 -*
import cv2
import numpy as np
from ..color_space import gray2bgr


def drawEpipolarLines(pts1, pts2, img1, img2):
    # https://opencv-python-tutroals.readthedocs.io/en/latest/py_tutorials/py_calib3d/py_epipolar_geometry/py_epipolar_geometry.html
    pts1 = np.int32(pts1)
    pts2 = np.int32(pts2)
    F, mask = cv2.findFundamentalMat(pts1,pts2,cv2.FM_LMEDS)

    # We select only inlier points
    pts1 = pts1[mask.ravel()==1]
    pts2 = pts2[mask.ravel()==1]

    def drawlines(img1,img2,lines,pts1,pts2):
        ''' img1 - image on which we draw the epilines for the points in img2
            lines - corresponding epilines '''
        r,c = img1.shape
        img1 = gray2bgr(img1) #cv2.cvtColor(img1,cv2.COLOR_GRAY2BGR)
        img2 = gray2bgr(img2) #cv2.cvtColor(img2,cv2.COLOR_GRAY2BGR)
        for r,pt1,pt2 in zip(lines,pts1,pts2):
            color = tuple(np.random.randint(0,255,3).tolist())
            x0,y0 = map(int, [0, -r[2]/r[1] ])
            x1,y1 = map(int, [c, -(r[2]+r[0]*c)/r[1] ])
            img1 = cv2.line(img1, (x0,y0), (x1,y1), color,1)
            img1 = cv2.circle(img1,tuple(pt1),5,color,-1)
            img2 = cv2.circle(img2,tuple(pt2),5,color,-1)
        return img1,img2

    # Find epilines corresponding to points in right image (second image) and
    # drawing its lines on left image
    lines1 = cv2.computeCorrespondEpilines(pts2.reshape(-1,1,2), 2,F)
    lines1 = lines1.reshape(-1,3)
    img5,img6 = drawlines(img1,img2,lines1,pts1,pts2)

    # Find epilines corresponding to points in left image (first image) and
    # drawing its lines on right image
    lines2 = cv2.computeCorrespondEpilines(pts1.reshape(-1,1,2), 1,F)
    lines2 = lines2.reshape(-1,3)
    img3,img4 = drawlines(img2,img1,lines2,pts2,pts1)

    return np.hstack((img5, img3))


def drawHorizontalLines(l, r, lines=True, thickness=1):
    """
    Display left/right stereo images and draw epipolar lines on image pairs.
    Images should be rectified to be meaningful.

    lines: draw lines - True/False
    thickness: how thick to draw lines, default is 1 pixel
    """
    n = np.hstack((l, r))
    if len(n.shape) < 3:
        n = gray2bgr(n)
    if lines:
        h, w = n.shape[:2]
        for r in range(0, h, 20):
            cv2.line(n,(0,r), (w,r), (200,0,0), thickness)
    return n

==> opencv_camera-0.11.0.tar.gz: opencv_camera-0.11.0/opencv_camera/display/lines.py <==
##############################################
# The MIT License (MIT)
# Copyright (c) 2014 Kevin Walchko
# see LICENSE for full details
##############################################
# -*- coding: utf-8 -*
import cv2
import numpy as np
from ..color_space import gray2bgr


def drawEpipolarLines(pts1, pts2, img1, img2):
    # https://opencv-python-tutroals.readthedocs.io/en/latest/py_tutorials/py_calib3d/py_epipolar_geometry/py_epipolar_geometry.html
    pts1 = np.int32(pts1)
    pts2 = np.int32(pts2)
    F, mask = cv2.findFundamentalMat(pts1,pts2,cv2.FM_LMEDS)

    # We select only inlier points
    pts1 = pts1[mask.ravel()==1]
    pts2 = pts2[mask.ravel()==1]

    def drawlines(img1,img2,lines,pts1,pts2):
        ''' img1 - image on which we draw the epilines for the points in img2
            lines - corresponding epilines '''
        r,c = img1.shape
        img1 = gray2bgr(img1) #cv2.cvtColor(img1,cv2.COLOR_GRAY2BGR)
        img2 = gray2bgr(img2) #cv2.cvtColor(img2,cv2.COLOR_GRAY2BGR)
        for r,pt1,pt2 in zip(lines,pts1,pts2):
            color = tuple(np.random.randint(0,255,3).tolist())
            x0,y0 = map(int, [0, -r[2]/r[1] ])
            x1,y1 = map(int, [c, -(r[2]+r[0]*c)/r[1] ])
            img1 = cv2.line(img1, (x0,y0), (x1,y1), color,1)
            img1 = cv2.circle(img1,tuple(pt1),5,color,-1)
            img2 = cv2.circle(img2,tuple(pt2),5,color,-1)
        return img1,img2

    # Find epilines corresponding to points in right image (second image) and
    # drawing its lines on left image
    lines1 = cv2.computeCorrespondEpilines(pts2.reshape(-1,1,2), 2,F)
    lines1 = lines1.reshape(-1,3)
    img5,img6 = drawlines(img1,img2,lines1,pts1,pts2)

    # Find epilines corresponding to points in left image (first image) and
    # drawing its lines on right image
    lines2 = cv2.computeCorrespondEpilines(pts1.reshape(-1,1,2), 1,F)
    lines2 = lines2.reshape(-1,3)
    img3,img4 = drawlines(img2,img1,lines2,pts2,pts1)

    return np.hstack((img5, img3))


def drawHorizontalLines(l, r, lines=True, thickness=1, step=20):
    """
    Display left/right stereo images and draw epipolar lines on image pairs.
    Images should be rectified to be meaningful.

    lines: draw lines - True/False
    thickness: how thick to draw lines, default is 1 pixel
    """
    n = np.hstack((l, r))
    if len(n.shape) < 3:
        n = gray2bgr(n)
    if lines:
        h, w = n.shape[:2]
        for r in range(0, h, step):
            cv2.line(n,(0,r), (w,r), (200,0,0), thickness)
    return n
